@@ -1,6 +1,5 @@
-#!/usr/bin/env python22
-#    TerminatorConfig - layered config classes
-#    Copyright (C) 2006-2010  cmsj@tenshu.net
+#  TerminatorConfig - layered config classes
+#  Copyright (C) 2006-2010  cmsj@tenshu.net
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -71,13 +70,12 @@ KeyError: 'ConfigBase::get_item: unknown key algo'
 
 """
 
-import platform
 import os
 from copy import copy
-from configobj.configobj import ConfigObj, flatten_errors
-from configobj.validate import Validator
-from borg import Borg
-from util import dbg, err, DEBUG, get_config_dir, dict_diff
+from configobj import ConfigObj, flatten_errors
+from validate import Validator
+from .borg import Borg
+from .util import dbg, err, DEBUG, get_config_dir, dict_diff
 
 from gi.repository import Gio
 
@@ -298,7 +296,7 @@ class Config(object):
             profile = options.profile
         dbg('Config::set_profile: Changing profile to %s' % profile)
         self.profile = profile
-        if not self.base.profiles.has_key(profile):
+        if profile not in self.base.profiles:
             dbg('Config::set_profile: %s does not exist, creating' % profile)
             self.base.profiles[profile] = copy(DEFAULTS['profiles']['default'])
 
@@ -313,7 +311,7 @@ class Config(object):
             # remove a profile
             err('Config::del_profile: Deleting in-use profile %s.' % profile)
             self.set_profile('default')
-        if self.base.profiles.has_key(profile):
+        if profile in self.base.profiles:
             del(self.base.profiles[profile])
         options = self.options_get()
         if options and options.profile == profile:
@@ -322,7 +320,7 @@ class Config(object):
 
     def rename_profile(self, profile, newname):
         """Rename a profile"""
-        if self.base.profiles.has_key(profile):
+        if profile in self.base.profiles:
             self.base.profiles[newname] = self.base.profiles[profile]
             del(self.base.profiles[profile])
             if profile == self.profile:
@@ -330,7 +328,7 @@ class Config(object):
 
     def list_profiles(self):
         """List all configured profiles"""
-        return(self.base.profiles.keys())
+        return(list(self.base.profiles.keys()))
 
     def add_layout(self, name, layout):
         """Add a new layout"""
@@ -342,18 +340,18 @@ class Config(object):
 
     def del_layout(self, layout):
         """Delete a layout"""
-        if self.base.layouts.has_key(layout):
+        if layout in self.base.layouts:
             del(self.base.layouts[layout])
 
     def rename_layout(self, layout, newname):
         """Rename a layout"""
-        if self.base.layouts.has_key(layout):
+        if layout in self.base.layouts:
             self.base.layouts[newname] = self.base.layouts[layout]
             del(self.base.layouts[layout])
 
     def list_layouts(self):
         """List all configured layouts"""
-        return(self.base.layouts.keys())
+        return(list(self.base.layouts.keys()))
 
     def connect_gsetting_callbacks(self):
         """Get system settings and create callbacks for changes"""
@@ -416,7 +414,7 @@ class Config(object):
         self.system_mono_font = None
         # Need to trigger a reconfigure to change active terminals immediately
         if "Terminator" not in globals():
-            from terminator import Terminator
+            from .terminator import Terminator
         Terminator().reconfigure()
 
     def save(self):
@@ -490,7 +488,7 @@ class ConfigBase(Borg):
         Borg.__init__(self, self.__class__.__name__)
 
         self.prepare_attributes()
-        import optionparse
+        from . import optionparse
         self.command_line_options = optionparse.options
         self.load()
 
@@ -585,7 +583,7 @@ class ConfigBase(Borg):
 
         configspec = ConfigObj(configspecdata)
         if DEBUG == True:
-            configspec.write(open('/tmp/terminator_configspec_debug.txt', 'w'))
+            configspec.write(open('/tmp/terminator_configspec_debug.txt', 'wb'))
         return(configspec)
 
     def load(self):
@@ -604,7 +602,7 @@ class ConfigBase(Borg):
         dbg('looking for config file: %s' % filename)
         try:
             configfile = open(filename, 'r')
-        except Exception, ex:
+        except Exception as ex:
             if not self.whined:
                 err('ConfigBase::load: Unable to open %s (%s)' % (filename, ex))
                 self.whined = True
@@ -617,7 +615,7 @@ class ConfigBase(Borg):
             parser = ConfigObj(configfile, configspec=configspec)
             validator = Validator()
             result = parser.validate(validator, preserve_errors=True)
-        except Exception, ex:
+        except Exception as ex:
             err('Unable to load configuration: %s' % ex)
             return
 
@@ -637,12 +635,12 @@ class ConfigBase(Borg):
             if section_name == 'profiles':
                 for profile in parser[section_name]:
                     dbg('ConfigBase::load: Processing profile: %s' % profile)
-                    if not section.has_key(section_name):
+                    if section_name not in section:
                         # FIXME: Should this be outside the loop?
                         section[profile] = copy(DEFAULTS['profiles']['default'])
                     section[profile].update(parser[section_name][profile])
             elif section_name == 'plugins':
-                if not parser.has_key(section_name):
+                if section_name not in parser:
                     continue
                 for part in parser[section_name]:
                     dbg('ConfigBase::load: Processing %s: %s' % (section_name,
@@ -657,7 +655,7 @@ class ConfigBase(Borg):
                            continue
                     section[layout] = parser[section_name][layout]
             elif section_name == 'keybindings':
-                if not parser.has_key(section_name):
+                if section_name not in parser:
                     continue
                 for part in parser[section_name]:
                     dbg('ConfigBase::load: Processing %s: %s' % (section_name,
@@ -669,7 +667,7 @@ class ConfigBase(Borg):
             else:
                 try:
                     section.update(parser[section_name])
-                except KeyError, ex:
+                except KeyError as ex:
                     dbg('ConfigBase::load: skipping missing section %s' %
                             section_name)
 
@@ -683,7 +681,7 @@ class ConfigBase(Borg):
     def save(self):
         """Save the config to a file"""
         dbg('ConfigBase::save: saving config')
-        parser = ConfigObj()
+        parser = ConfigObj(encoding='utf-8')
         parser.indent_type = '  '
 
         for section_name in ['global_config', 'keybindings']:
@@ -711,21 +709,26 @@ class ConfigBase(Borg):
         if not os.path.isdir(config_dir):
             os.makedirs(config_dir)
         try:
-            parser.write(open(self.command_line_options.config, 'w'))
-        except Exception, ex:
+            temp_file = self.command_line_options.config + '.tmp'
+
+            with open(temp_file, 'wb') as fh:
+                parser.write(fh)
+
+            os.rename(temp_file, self.command_line_options.config)
+        except Exception as ex:
             err('ConfigBase::save: Unable to save config: %s' % ex)
 
     def get_item(self, key, profile='default', plugin=None, default=None):
         """Look up a configuration item"""
-        if not self.profiles.has_key(profile):
+        if profile not in self.profiles:
             # Hitting this generally implies a bug
             profile = 'default'
 
-        if self.global_config.has_key(key):
+        if key in self.global_config:
             dbg('ConfigBase::get_item: %s found in globals: %s' %
                     (key, self.global_config[key]))
             return(self.global_config[key])
-        elif self.profiles[profile].has_key(key):
+        elif key in self.profiles[profile]:
             dbg('ConfigBase::get_item: %s found in profile %s: %s' % (
                     key, profile, self.profiles[profile][key]))
             return(self.profiles[profile][key])
@@ -745,14 +748,14 @@ class ConfigBase(Borg):
         dbg('ConfigBase::set_item: Setting %s=%s (profile=%s, plugin=%s)' %
                 (key, value, profile, plugin))
 
-        if self.global_config.has_key(key):
+        if key in self.global_config:
             self.global_config[key] = value
-        elif self.profiles[profile].has_key(key):
+        elif key in self.profiles[profile]:
             self.profiles[profile][key] = value
         elif key == 'keybindings':
             self.keybindings = value
         elif plugin is not None:
-            if not self.plugins.has_key(plugin):
+            if plugin not in self.plugins:
                 self.plugins[plugin] = {}
             self.plugins[plugin][key] = value
         else:
@@ -762,7 +765,7 @@ class ConfigBase(Borg):
 
     def get_plugin(self, plugin):
         """Return a whole tree for a plugin"""
-        if self.plugins.has_key(plugin):
+        if plugin in self.plugins:
             return(self.plugins[plugin])
 
     def set_plugin(self, plugin, tree):
@@ -797,7 +800,7 @@ class ConfigBase(Borg):
 
     def get_layout(self, layout):
         """Return a layout"""
-        if self.layouts.has_key(layout):
+        if layout in self.layouts:
             return(self.layouts[layout])
         else:
             err('layout does not exist: %s' % layout)
